@@ -46,3 +46,9 @@ class Database:
         if self._instance is None or not self._instance.is_open():
             self.reconnect()
 
+    @staticmethod
+    def success(result):
+        if type(result) is dict: # an insert happened
+            return result["errors"] is 0
+        else: # a select happened
+            return len(list(result)) > 0
\ No newline at end of file
